@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2025 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -15,7 +15,6 @@
 # -----------------------------------------------------------------------
 
 import re
-import string
 
 
 def language(hdr):
@@ -40,7 +39,7 @@ def _parse(hdr, result):
     name = _re_token.match(hdr, pos)
     if not name:
       raise AcceptLanguageParseError()
-    a = result.item_class(string.lower(name.group(1)))
+    a = result.item_class(name.group(1).lower())
     pos = name.end()
     while 1:
       # are we looking at a parameter?
@@ -56,7 +55,7 @@ def _parse(hdr, result):
         # the "=" was probably missing
         continue
 
-      pname = string.lower(match.group(1))
+      pname = match.group(1).lower()
       if pname == 'q' or pname == 'qs':
         try:
           a.quality = float(match.group(2))
@@ -70,7 +69,7 @@ def _parse(hdr, result):
           # bad float literal
           pass
       elif pname == 'charset':
-        a.charset = string.lower(match.group(2))
+        a.charset = match.group(2).lower()
 
     result.append(a)
     if hdr[pos:pos+1] == ',':
