@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2025 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -16,7 +16,6 @@
 
 import sys
 import os
-import string
 import ConfigParser
 import fnmatch
 
@@ -54,32 +53,32 @@ import fnmatch
 #         PER-ROOT          PER-VHOST            BASE
 #       
 #                         ,-----------.     ,-----------.
-#                         | vhost-*/  |     |           |
+#                         | vhost-*|  |     |           |
 #                         |  general  | --> |  general  |
 #                         |           |     |           |
 #                         `-----------'     `-----------'
 #       ,-----------.     ,-----------.     ,-----------.
-#       |  root-*/  |     | vhost-*/  |     |           |
+#       |  root-*|  |     | vhost-*|  |     |           |
 #       |  options  | --> |  options  | --> |  options  |
 #       |           |     |           |     |           |
 #       `-----------'     `-----------'     `-----------'
 #       ,-----------.     ,-----------.     ,-----------.
-#       |  root-*/  |     | vhost-*/  |     |           |
+#       |  root-*|  |     | vhost-*|  |     |           |
 #       | templates | --> | templates | --> | templates |
 #       |           |     |           |     |           |
 #       `-----------'     `-----------'     `-----------'
 #       ,-----------.     ,-----------.     ,-----------.
-#       |  root-*/  |     | vhost-*/  |     |           |
+#       |  root-*|  |     | vhost-*|  |     |           |
 #       | utilities | --> | utilities | --> | utilities |
 #       |           |     |           |     |           |
 #       `-----------'     `-----------'     `-----------'
 #                         ,-----------.     ,-----------.
-#                         | vhost-*/  |     |           |
+#                         | vhost-*|  |     |           |
 #                         |   cvsdb   | --> |   cvsdb   |
 #                         |           |     |           |
 #                         `-----------'     `-----------'
 #       ,-----------.     ,-----------.     ,-----------.
-#       |  root-*/  |     | vhost-*/  |     |           |
+#       |  root-*|  |     | vhost-*|  |     |           |
 #       |  authz-*  | --> |  authz-*  | --> |  authz-*  |
 #       |           |     |           |     |           |
 #       `-----------'     `-----------'     `-----------'
@@ -113,6 +112,7 @@ class Config:
     # Configuration values with multiple, comma-separated values.
     'allowed_views',
     'binary_mime_types',
+    'dir_ignored_files',
     'custom_log_formatting',
     'cvs_roots',
     'kv_files',
@@ -173,12 +173,12 @@ class Config:
 
     for fname in self.general.kv_files:
       if fname[0] == '[':
-        idx = string.index(fname, ']')
-        parts = string.split(fname[1:idx], '.')
-        fname = string.strip(fname[idx+1:])
+        idx = fname.index(']')
+        parts = fname[1:idx].split('.')
+        fname = fname[idx+1:].strip()
       else:
         parts = [ ]
-      fname = string.replace(fname, '%lang%', language)
+      fname = fname.replace('%lang%', language)
 
       parser = ConfigParser.ConfigParser()
       parser.optionxform = lambda x: x # don't case-normalize option names.
@@ -210,7 +210,7 @@ class Config:
     for opt in parser.options(section):
       value = parser.get(section, opt)
       if opt in self._force_multi_value:
-        value = map(string.strip, filter(None, string.split(value, ',')))
+        value = map(lambda x: x.strip(), filter(None, value.split(',')))
       else:
         try:
           value = int(value)
@@ -245,7 +245,7 @@ class Config:
     at all, return None.  And if it's an override section but not an
     allowed one, raise IllegalOverrideSection."""
 
-    cv = '%s-%s/' % (sectype, secspec)
+    cv = '%s-%s|' % (sectype, secspec)
     lcv = len(cv)
     if section[:lcv] != cv:
       return None
@@ -268,11 +268,11 @@ class Config:
         self._process_section(parser, section, base_section)
 
   def _find_canon_vhost(self, parser, vhost):
-    vhost = string.split(string.lower(vhost), ':')[0]  # lower-case, no port
+    vhost = vhost.lower().split(':')[0]  # lower-case, no port
     for canon_vhost in parser.options('vhosts'):
       value = parser.get('vhosts', canon_vhost)
-      patterns = map(string.lower, map(string.strip,
-                                       filter(None, string.split(value, ','))))
+      patterns = map(lambda x: x.lower().strip(),
+                     filter(None, value.split(',')))
       for pat in patterns:
         if fnmatch.fnmatchcase(vhost, pat):
           return canon_vhost
@@ -303,16 +303,6 @@ class Config:
     if did_overlay:
       self.root_options_overlayed = 1
 
-  def _get_parser_items(self, parser, section):
-    """Basically implement ConfigParser.items() for pre-Python-2.3 versions."""
-    try:
-      return self.parser.items(section)
-    except AttributeError:
-      d = {}
-      for option in parser.options(section):
-        d[option] = parser.get(section, option)
-      return d.items()
-
   def get_authorizer_and_params_hack(self, rootname):
     """Return a 2-tuple containing the name and parameters of the
     authorizer configured for use with ROOTNAME.
@@ -335,7 +325,7 @@ class Config:
     # Figure out the authorizer by searching first for a per-root
     # override, then falling back to the base/vhost configuration.
     authorizer = None
-    root_options_section = 'root-%s/options' % (rootname)
+    root_options_section = 'root-%s|options' % (rootname)
     if self.parser.has_section(root_options_section) \
        and self.parser.has_option(root_options_section, 'authorizer'):
       authorizer = self.parser.get(root_options_section, 'authorizer')
@@ -354,10 +344,10 @@ class Config:
       sub_config = getattr(self, authz_section)
       for attr in dir(sub_config):
         params[attr] = getattr(sub_config, attr)
-    root_authz_section = 'root-%s/authz-%s' % (rootname, authorizer)
+    root_authz_section = 'root-%s|authz-%s' % (rootname, authorizer)
     for section in self.parser.sections():
       if section == root_authz_section:
-        for key, value in self._get_parser_items(self.parser, section):
+        for key, value in self.parser.items():
           params[key] = value
     return authorizer, params
 
@@ -393,7 +383,6 @@ class Config:
       self.utilities.cvsnt = 'cvs'
     else:
       self.utilities.cvsnt = None
-    self.utilities.svn = ''
     self.utilities.diff = ''
     self.utilities.cvsgraph = ''
 
@@ -405,6 +394,7 @@ class Config:
     self.options.custom_log_formatting = []
     self.options.default_file_view = "log"
     self.options.binary_mime_types = []
+    self.options.dir_ignored_files = []
     self.options.http_expiration_time = 600
     self.options.generate_etags = 1
     self.options.svn_ignore_mimetype = 0
@@ -424,7 +414,7 @@ class Config:
     self.options.hr_ignore_keyword_subst = 1
     self.options.hr_intraline = 0
     self.options.allow_compress = 0
-    self.options.template_dir = "templates"
+    self.options.template_dir = "templates/default"
     self.options.docroot = None
     self.options.show_subdir_lastmod = 0
     self.options.show_roots_lastmod = 0
@@ -439,11 +429,13 @@ class Config:
     self.options.detect_encoding = 0
     self.options.use_cvsgraph = 0
     self.options.cvsgraph_conf = "cvsgraph.conf"
+    self.options.allowed_cvsgraph_useropts = []
     self.options.use_re_search = 0
     self.options.dir_pagesize = 0
     self.options.log_pagesize = 0
     self.options.log_pagesextra = 3
     self.options.limit_changes = 100
+    self.options.stacktraces = 0
 
     self.templates.diff = None
     self.templates.directory = None
@@ -451,7 +443,6 @@ class Config:
     self.templates.file = None
     self.templates.graph = None
     self.templates.log = None
-    self.templates.query = None
     self.templates.query_form = None
     self.templates.query_results = None
     self.templates.roots = None
@@ -467,8 +458,6 @@ class Config:
     self.cvsdb.row_limit = 1000
     self.cvsdb.rss_row_limit = 100
     self.cvsdb.check_database_for_root = 0
-
-    self.query.viewvc_base_url = None
     
 def _startswith(somestr, substr):
   return somestr[:len(substr)] == substr
@@ -476,11 +465,11 @@ def _startswith(somestr, substr):
 def _parse_roots(config_name, config_value):
   roots = { }
   for root in config_value:
-    pos = string.find(root, ':')
-    if pos < 0:
+    try:
+      name, path = root.split(':', 1)
+    except:
       raise MalformedRoot(config_name, root)
-    name, path = map(string.strip, (root[:pos], root[pos+1:]))
-    roots[name] = path
+    roots[name.strip()] = path.strip()
   return roots
 
 class ViewVCConfigurationError(Exception):
@@ -506,10 +495,3 @@ class MalformedRoot(ViewVCConfigurationError):
 
 class _sub_config:
   pass
-
-if not hasattr(sys, 'hexversion'):
-  # Python 1.5 or 1.5.1. fix the syntax for ConfigParser options.
-  import regex
-  ConfigParser.option_cre = regex.compile('^\([-A-Za-z0-9._]+\)\(:\|['
-                                          + string.whitespace
-                                          + ']*=\)\(.*\)$')
