@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2025 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -16,7 +16,6 @@
 # -----------------------------------------------------------------------
 
 import types
-import string
 import os
 import sys
 import re
@@ -34,10 +33,10 @@ server = None
 # into HTML attributes.
 def escape(s):
   s = str(s)
-  s = string.replace(s, '&', '&amp;')
-  s = string.replace(s, '>', '&gt;')
-  s = string.replace(s, '<', '&lt;')
-  s = string.replace(s, '"', "&quot;")
+  s = s.replace('&', '&amp;')
+  s = s.replace('>', '&gt;')
+  s = s.replace('<', '&lt;')
+  s = s.replace('"', "&quot;")
   return s
 
   
@@ -211,9 +210,6 @@ class WsgiServer(Server):
     global server
     server = self
 
-    global cgi
-    import cgi
-
   def addheader(self, name, value):
     self._headers.append((name, value))
 
