@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 2006-2017 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 2006-2025 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -12,7 +12,6 @@
 # (c) 2006 Sergey Lapin <slapin@dataart.com>
 
 import vcauth
-import string
 import os.path
 import debug
 
@@ -37,9 +36,9 @@ class ViewVCAuthorizer(vcauth.GenericViewVCAuthorizer):
     # See if the admin wants us to do case normalization of usernames.
     self.force_username_case = params.get('force_username_case')
     if self.force_username_case == "upper":
-      self.username = username and string.upper(username) or username
+      self.username = username and username.upper() or username
     elif self.force_username_case == "lower":
-      self.username = username and string.lower(username) or username
+      self.username = username and username.lower() or username
     elif not self.force_username_case:
       self.username = username
     else:
@@ -69,6 +68,12 @@ class ViewVCAuthorizer(vcauth.GenericViewVCAuthorizer):
     except:
       raise debug.ViewVCException("Unable to parse configured authzfile file")
 
+    # Ignore context; assume the authz file only has the repository URL's
+    # basename, just like mod_dav_svn requires it.
+    # Perhaps it's better to just use the repository directory's basename.
+    root_parts = rootname.split('/')
+    repo_name = root_parts[-1]
+
     # Figure out if there are any aliases for the current username
     aliases = []
     if cp.has_section('aliases'):
@@ -107,9 +112,9 @@ class ViewVCAuthorizer(vcauth.GenericViewVCAuthorizer):
         all_groups.append(groupname)
         group_member = 0
         groupname = groupname.strip()
-        entries = string.split(cp.get('groups', groupname), ',')
+        entries = cp.get('groups', groupname).split(',')
         for entry in entries:
-          entry = string.strip(entry)
+          entry = entry.strip()
           if entry == self.username:
             group_member = 1
             break
@@ -150,13 +155,13 @@ class ViewVCAuthorizer(vcauth.GenericViewVCAuthorizer):
       # Figure if this path is explicitly allowed or denied to USERNAME.
       allow = deny = 0
       for user in cp.options(section):
-        user = string.strip(user)
+        user = user.strip()
         if _userspec_matches_user(user):
           # See if the 'r' permission is among the ones granted to
           # USER.  If so, we can stop looking.  (Entry order is not
           # relevant -- we'll use the most permissive entry, meaning
           # one 'allow' is all we need.)
-          allow = string.find(cp.get(section, user), 'r') != -1
+          allow = cp.get(section, user).find('r') != -1
           deny = not allow
           if allow:
             break
@@ -185,8 +190,8 @@ class ViewVCAuthorizer(vcauth.GenericViewVCAuthorizer):
       if section.find(':') == -1:
         path = section
       else:
-        name, path = string.split(section, ':', 1)
-        if name == rootname:
+        name, path = section.split(':', 1)
+        if name == repo_name:
           root_sections.append(section)
         continue
 
@@ -197,14 +202,14 @@ class ViewVCAuthorizer(vcauth.GenericViewVCAuthorizer):
       # USERNAME, record it.
       if allow or deny:
         if path != '/':
-          path = '/' + string.join(filter(None, string.split(path, '/')), '/')
+          path = '/' + '/'.join(filter(None, path.split('/')))
         paths_for_root[path] = allow
 
     # Okay.  Superimpose those root-specific values now.
     for section in root_sections:
 
       # Get the path again.
-      name, path = string.split(section, ':', 1)
+      name, path = section.split(':', 1)
       
       # Check for a specific access determination.
       allow, deny = _process_access_section(section)
@@ -213,7 +218,7 @@ class ViewVCAuthorizer(vcauth.GenericViewVCAuthorizer):
       # USERNAME, record it.
       if allow or deny:
         if path != '/':
-          path = '/' + string.join(filter(None, string.split(path, '/')), '/')
+          path = '/' + '/'.join(filter(None, path.split('/')))
         paths_for_root[path] = allow
 
     # If the root isn't readable, there's no point in caring about all
@@ -273,7 +278,7 @@ class ViewVCAuthorizer(vcauth.GenericViewVCAuthorizer):
       return 0
     parts = path_parts[:]
     while parts:
-      path = '/' + string.join(parts, '/')
+      path = '/' + '/'.join(parts)
       if paths.has_key(path):
         return paths[path]
       del parts[-1]
