@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2025 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -11,6 +11,11 @@
 # -----------------------------------------------------------------------
 import os
 import os.path
+import time
+
+
+def cvs_strptime(timestr):
+  return time.strptime(timestr, '%Y/%m/%d %H:%M:%S')[:-1] + (0,)
 
 
 def canonicalize_rootpath(rootpath):
