@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2025 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -18,14 +18,17 @@ import os
 import os.path
 import sys
 import stat
-import string
 import re
 import time
+import calendar
 
 # ViewVC libs
-import compat
 import popen
+import vclib.ccvs
 
+def _path_join(path_parts):
+  return '/'.join(path_parts)
+  
 class BaseCVSRepository(vclib.Repository):
   def __init__(self, name, rootpath, authorizer, utilities):
     if not os.path.isdir(rootpath):
@@ -81,7 +84,7 @@ class BaseCVSRepository(vclib.Repository):
   def listdir(self, path_parts, rev, options):
     if self.itemtype(path_parts, rev) != vclib.DIR:  # does auth-check
       raise vclib.Error("Path '%s' is not a directory."
-                        % (string.join(path_parts, "/")))
+                        % (_path_join(path_parts)))
     
     # Only RCS files (*,v) and subdirs are returned.
     data = [ ]
@@ -138,15 +141,14 @@ class BaseCVSRepository(vclib.Repository):
     if root:
       ret = ret_file
     else:
-      ret = string.join(ret_parts, "/")
+      ret = _path_join(ret_parts)
     if v:
       ret = ret + ",v"
     return ret
 
   def isexecutable(self, path_parts, rev):
     if self.itemtype(path_parts, rev) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts)))
     rcsfile = self.rcsfile(path_parts, 1)
     return os.access(rcsfile, os.X_OK)
   
@@ -181,8 +183,7 @@ class BinCVSRepository(BaseCVSRepository):
         boolean. true to use the original keyword substitution values.
     """
     if self.itemtype(path_parts, rev) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts)))
     if not rev or rev == 'HEAD' or rev == 'MAIN':
       rev_flag = '-p'
     else:
@@ -256,7 +257,7 @@ class BinCVSRepository(BaseCVSRepository):
     """
     if self.itemtype(path_parts, rev) != vclib.DIR:  # does auth-check
       raise vclib.Error("Path '%s' is not a directory."
-                        % (string.join(path_parts, "/")))
+                        % (_path_join(path_parts)))
 
     subdirs = options.get('cvs_subdirs', 0)
     entries_to_fetch = []
@@ -293,8 +294,7 @@ class BinCVSRepository(BaseCVSRepository):
     """
 
     if self.itemtype(path_parts, rev) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts)))
     
     # Invoke rlog
     rcsfile = self.rcsfile(path_parts, 1)
@@ -339,8 +339,7 @@ class BinCVSRepository(BaseCVSRepository):
 
   def annotate(self, path_parts, rev=None, include_text=False):
     if self.itemtype(path_parts, rev) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts)))
                         
     from vclib.ccvs import blame
     source = blame.BlameSource(self.rcsfile(path_parts, 1), rev, include_text)
@@ -357,11 +356,9 @@ class BinCVSRepository(BaseCVSRepository):
       ignore_keyword_subst - boolean, ignore keyword substitution
     """
     if self.itemtype(path_parts1, rev1) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts1, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts1)))
     if self.itemtype(path_parts2, rev2) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts2, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts2)))
     
     args = vclib._diff_args(type, options)
     if options.get('ignore_keyword_subst', 0):
@@ -569,7 +566,7 @@ def _remove_tag(tag):
 
 def _revision_tuple(revision_string):
   """convert a revision number into a tuple of integers"""
-  t = tuple(map(int, string.split(revision_string, '.')))
+  t = tuple(map(int, revision_string.split('.')))
   if len(t) % 2 == 0:
     return t
   raise ValueError
@@ -577,7 +574,7 @@ def _revision_tuple(revision_string):
 def _tag_tuple(revision_string):
   """convert a revision number or branch number into a tuple of integers"""
   if revision_string:
-    t = map(int, string.split(revision_string, '.'))
+    t = map(int, revision_string.split('.'))
     l = len(t)
     if l == 1:
       return ()
@@ -722,7 +719,7 @@ def _parse_log_header(fp):
 
     if state == 1:
       if line[0] == '\t':
-        [ tag, rev ] = map(string.strip, string.split(line, ':'))
+        [ tag, rev ] = map(lambda x: x.strip(), line.split(':'))
         taginfo[tag] = rev
       else:
         # oops. this line isn't tag info. stop parsing tags.
@@ -730,7 +727,7 @@ def _parse_log_header(fp):
 
     if state == 2:
       if line[0] == '\t':
-        [ locker, rev ] = map(string.strip, string.split(line, ':'))
+        [ locker, rev ] = map(lambda x: x.strip(), line.split(':'))
         lockinfo[rev] = locker
       else:
         # oops. this line isn't lock info. stop parsing tags.
@@ -839,7 +836,7 @@ def _parse_log_entry(fp):
     return None, eof
 
   # parse out a time tuple for the local time
-  tm = compat.cvs_strptime(match.group(1))
+  tm = vclib.ccvs.cvs_strptime(match.group(1))
 
   # rlog seems to assume that two-digit years are 1900-based (so, "04"
   # comes out as "1904", not "2004").
@@ -850,7 +847,7 @@ def _parse_log_entry(fp):
       tm[0] = tm[0] + 100
     if tm[0] < EPOCH:
       raise ValueError, 'invalid year'
-  date = compat.timegm(tm)
+  date = calendar.timegm(tm)
 
   return Revision(rev, date,
                   # author, state, lines changed
