@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2025 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -11,7 +11,6 @@
 # -----------------------------------------------------------------------
 
 import os
-import string
 import re
 import cStringIO
 import tempfile
@@ -22,7 +21,8 @@ import blame
 
 ### The functionality shared with bincvs should probably be moved to a
 ### separate module
-from bincvs import BaseCVSRepository, Revision, Tag, _file_log, _log_path, _logsort_date_cmp, _logsort_rev_cmp
+from bincvs import BaseCVSRepository, Revision, Tag, _file_log, _log_path, _logsort_date_cmp, _logsort_rev_cmp, _path_join
+
 
 class CCVSRepository(BaseCVSRepository):
   def dirlogs(self, path_parts, rev, entries, options):
@@ -44,7 +44,7 @@ class CCVSRepository(BaseCVSRepository):
     """
     if self.itemtype(path_parts, rev) != vclib.DIR:  # does auth-check
       raise vclib.Error("Path '%s' is not a directory."
-                        % (string.join(path_parts, "/")))
+                        % (part2path(path_parts)))
     entries_to_fetch = []
     for entry in entries:
       if vclib.check_path_access(self, path_parts + [entry.name], None, rev):
@@ -94,8 +94,7 @@ class CCVSRepository(BaseCVSRepository):
         dictionary of Tag objects for all tags encountered
     """
     if self.itemtype(path_parts, rev) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts)))
 
     path = self.rcsfile(path_parts, 1)
     sink = TreeSink()
@@ -111,7 +110,7 @@ class CCVSRepository(BaseCVSRepository):
       filtered_revs.sort(_logsort_date_cmp)
     elif sortby == vclib.SORTBY_REV:
       filtered_revs.sort(_logsort_rev_cmp)
-      
+
     if len(filtered_revs) < first:
       return []
     if limit:
@@ -120,16 +119,14 @@ class CCVSRepository(BaseCVSRepository):
 
   def rawdiff(self, path_parts1, rev1, path_parts2, rev2, type, options={}):
     if self.itemtype(path_parts1, rev1) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts1, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts1)))
     if self.itemtype(path_parts2, rev2) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts2, "/")))
-    
-    temp1 = tempfile.mktemp()
-    open(temp1, 'wb').write(self.openfile(path_parts1, rev1, {})[0].getvalue())
-    temp2 = tempfile.mktemp()
-    open(temp2, 'wb').write(self.openfile(path_parts2, rev2, {})[0].getvalue())
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts2)))
+
+    fd1, temp1 = tempfile.mkstemp()
+    os.fdopen(fd1, 'wb').write(self.openfile(path_parts1, rev1, {})[0].getvalue())
+    fd2, temp2 = tempfile.mkstemp()
+    os.fdopen(fd2, 'wb').write(self.openfile(path_parts2, rev2, {})[0].getvalue())
 
     r1 = self.itemlog(path_parts1, rev1, vclib.SORTBY_DEFAULT, 0, 0, {})[-1]
     r2 = self.itemlog(path_parts2, rev2, vclib.SORTBY_DEFAULT, 0, 0, {})[-1]
@@ -144,8 +141,7 @@ class CCVSRepository(BaseCVSRepository):
 
   def annotate(self, path_parts, rev=None, include_text=False):
     if self.itemtype(path_parts, rev) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts)))
     source = blame.BlameSource(self.rcsfile(path_parts, 1), rev, include_text)
     return source, source.revision
 
@@ -154,13 +150,12 @@ class CCVSRepository(BaseCVSRepository):
 
   def openfile(self, path_parts, rev, options):
     if self.itemtype(path_parts, rev) != vclib.FILE:  # does auth-check
-      raise vclib.Error("Path '%s' is not a file."
-                        % (string.join(path_parts, "/")))
+      raise vclib.Error("Path '%s' is not a file." % (_path_join(path_parts)))
     path = self.rcsfile(path_parts, 1)
     sink = COSink(rev)
     rcsparse.parse(open(path, 'rb'), sink)
     revision = sink.last and sink.last.string
-    return cStringIO.StringIO(string.join(sink.sstext.text, "\n")), revision
+    return cStringIO.StringIO(''.join(sink.sstext.text)), revision
 
 class MatchingSink(rcsparse.Sink):
   """Superclass for sinks that search for revisions based on tag or number"""
@@ -218,20 +213,20 @@ class InfoSink(MatchingSink):
     if not self.saw_revision:
       #self.entry.errors.append("No revisions exist on %s" % (view_tag or "MAIN"))
       self.entry.absent = 1
-    
+
   def set_locker(self, rev, locker):
     self.lockinfo[rev] = locker
-    
+
   def define_revision(self, revision, date, author, state, branches, next):
     self.saw_revision = True
-    
+
     if self.perfect_match:
       return
 
     tag = self.find_tag
     rev = Revision(revision, date, author, state == "dead")
     rev.lockinfo = self.lockinfo.get(revision)
-    
+
     # perfect match if revision number matches tag number or if
     # revision is on trunk and tag points to trunk.  imperfect match
     # if tag refers to a branch and either a) this revision is the
@@ -271,7 +266,7 @@ class TreeSink(rcsparse.Sink):
     self.head = None
     self.default_branch = None
     self.lockinfo = { }
-    
+
   def set_head_revision(self, revision):
     self.head = revision
 
@@ -280,7 +275,7 @@ class TreeSink(rcsparse.Sink):
 
   def set_locker(self, rev, locker):
     self.lockinfo[rev] = locker
-    
+
   def define_tag(self, name, revision):
     # check !tags.has_key(tag_name)
     self.tags[name] = revision
@@ -299,41 +294,53 @@ class TreeSink(rcsparse.Sink):
     deled = 0
     if self.head != revision:
       changed = 1
-      lines = string.split(text, '\n')
+      lines = text.split('\n')
       idx = 0
       while idx < len(lines):
         command = lines[idx]
         dmatch = self.d_command.match(command)
         idx = idx + 1
         if dmatch:
-          deled = deled + string.atoi(dmatch.group(2))
+          deled = deled + int(dmatch.group(2))
         else:
           amatch = self.a_command.match(command)
           if amatch:
-            count = string.atoi(amatch.group(2))
+            count = int(amatch.group(2))
             added = added + count
             idx = idx + count
           elif command:
-            raise "error while parsing deltatext: %s" % command
+            raise vclib.Error("error while parsing deltatext: %s" % command)
 
     if len(rev.number) == 2:
       rev.next_changed = changed and "+%i -%i" % (deled, added)
     else:
       rev.changed = changed and "+%i -%i" % (added, deled)
 
+
+def _msplit(s):
+  r"""Split (str) S into an array of lines.
+
+  Only \n is a line separator. The line endings are part of the lines."""
+
+  lines = [line + '\n' for line in s.split('\n')]
+  if lines[-1] == '\n':
+    del lines[-1]
+  else:
+    lines[-1] = lines[-1][:-1]
+  return lines
+
+
 class StreamText:
-  d_command = re.compile('^d(\d+)\\s(\\d+)')
-  a_command = re.compile('^a(\d+)\\s(\\d+)')
+  d_command = re.compile('^d(\d+)\\s(\\d+)\n')
+  a_command = re.compile('^a(\d+)\\s(\\d+)\n')
 
   def __init__(self, text):
-    self.text = string.split(text, "\n")
+    self.text = _msplit(text)
 
   def command(self, cmd):
     adjust = 0
     add_lines_remaining = 0
-    diffs = string.split(cmd, "\n")
-    if diffs[-1] == "":
-      del diffs[-1]
+    diffs = _msplit(cmd)
     if len(diffs) == 0:
       return
     if diffs[0] == "":
@@ -341,6 +348,9 @@ class StreamText:
     for command in diffs:
       if add_lines_remaining > 0:
         # Insertion lines from a prior "a" command
+        # Note: Don't check if we insert a string which does not end
+        # with b'\n' before an existing line. Some CVS implementation
+        # can produce such edit commands.
         self.text.insert(start_line + adjust, command)
         add_lines_remaining = add_lines_remaining - 1
         adjust = adjust + 1
@@ -349,22 +359,22 @@ class StreamText:
       amatch = self.a_command.match(command)
       if dmatch:
         # "d" - Delete command
-        start_line = string.atoi(dmatch.group(1))
-        count      = string.atoi(dmatch.group(2))
+        start_line = int(dmatch.group(1))
+        count      = int(dmatch.group(2))
         begin = start_line + adjust - 1
         del self.text[begin:begin + count]
         adjust = adjust - count
       elif amatch:
         # "a" - Add command
-        start_line = string.atoi(amatch.group(1))
-        count      = string.atoi(amatch.group(2))
+        start_line = int(amatch.group(1))
+        count      = int(amatch.group(2))
         add_lines_remaining = count
       else:
         raise RuntimeError, 'Error parsing diff commands'
 
 def secondnextdot(s, start):
   # find the position the second dot after the start index.
-  return string.find(s, '.', string.find(s, '.', start) + 1)
+  return s.find('.', s.find('.', start) + 1)
 
 
 class COSink(MatchingSink):
