@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2025 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -15,7 +15,6 @@
 import vclib
 import sys
 import os
-import string
 import re
 import tempfile
 import time
@@ -150,7 +149,7 @@ class LogCollector:
       if changed_path != self.path:
         # If a parent of our path was copied, our "next previous"
         # (huh?) path will exist elsewhere (under the copy source).
-        if (string.rfind(self.path, changed_path) == 0) and \
+        if (self.path.rfind(changed_path) == 0) and \
                self.path[len(changed_path)] == '/':
           change = paths[changed_path]
           if change.copyfrom_path:
@@ -168,12 +167,12 @@ class LogCollector:
     
 def cat_to_tempfile(svnrepos, path, rev):
   """Check out file revision to temporary file"""
-  temp = tempfile.mktemp()
-  stream = core.svn_stream_from_aprfile(temp)
+  fd, temp = tempfile.mkstemp()
+  fp = os.fdopen(fd, 'wb')
   url = svnrepos._geturl(path)
-  client.svn_client_cat(core.Stream(stream), url, _rev2optrev(rev),
+  client.svn_client_cat(fp, url, _rev2optrev(rev),
                         svnrepos.ctx)
-  core.svn_stream_close(stream)
+  fp.close()
   return temp
 
 class SelfCleanFP:
@@ -485,7 +484,7 @@ class RemoteSubversionRepository(vclib.Repository):
     return dirent.size
     
   def _getpath(self, path_parts):
-    return string.join(path_parts, '/')
+    return '/'.join(path_parts)
 
   def _getrev(self, rev):
     if rev is None or rev == 'HEAD':
