@@ -1,6 +1,6 @@
 # -*-python-*-
 #
-# Copyright (C) 1999-2017 The ViewCVS Group. All Rights Reserved.
+# Copyright (C) 1999-2025 The ViewCVS Group. All Rights Reserved.
 #
 # By using this file, you agree to the terms and conditions set forth in
 # the LICENSE.html file which can be found at the top level of the ViewVC
@@ -14,7 +14,7 @@
 #
 # -----------------------------------------------------------------------
 
-import os, sys, traceback, string, thread
+import os, sys, traceback, thread
 try:
   import win32api
 except ImportError, e:
@@ -40,9 +40,9 @@ def CommandLine(command, args):
   """Convert an executable path and a sequence of arguments into a command
   line that can be passed to CreateProcess"""
 
-  cmd = "\"" + string.replace(command, "\"", "\"\"") + "\""
+  cmd = "\"" + command.replace("\"", "\"\"") + "\""
   for arg in args:
-    cmd = cmd + " \"" + string.replace(arg, "\"", "\"\"") + "\""
+    cmd = cmd + " \"" + arg.replace("\"", "\"\"") + "\""
   return cmd
 
 def CreateProcess(cmd, hStdInput, hStdOutput, hStdError):
@@ -109,13 +109,13 @@ def CreatePipe(readInheritable, writeInheritable):
 
 def File2FileObject(pipe, mode):
   """Make a C stdio file object out of a win32 file handle"""
-  if string.find(mode, 'r') >= 0:
+  if mode.find('r') >= 0:
     wmode = os.O_RDONLY
-  elif string.find(mode, 'w') >= 0:
+  elif mode.find('w') >= 0:
     wmode = os.O_WRONLY
-  if string.find(mode, 'b') >= 0:
+  if mode.find('b') >= 0:
     wmode = wmode | os.O_BINARY
-  if string.find(mode, 't') >= 0:
+  if mode.find('t') >= 0:
     wmode = wmode | os.O_TEXT
   return os.fdopen(msvcrt.open_osfhandle(pipe.Detach(),wmode),mode)
 
@@ -184,7 +184,7 @@ def SpoolWorker(srcHandle, destHandle, outFiles, doneEvent):
         hr, data = win32file.ReadFile(srcHandle, buffer)
         #print >> SPOOL_ERROR, "ReadFile returned '%s', '%s'" % (str(hr), str(data)); SPOOL_ERROR.flush()
         if hr != 0:
-          raise "win32file.ReadFile returned %i, '%s'" % (hr, data)
+          raise Exception("win32file.ReadFile returned %i, '%s'" % (hr, data))
         elif len(data) == 0:
           break
       except pywintypes.error, e:
@@ -205,7 +205,7 @@ def SpoolWorker(srcHandle, destHandle, outFiles, doneEvent):
         hr, bytes = win32file.WriteFile(destHandle, data)
         #print >> SPOOL_ERROR, "WriteFile() passed %i bytes and returned %i, %i" % (len(data), hr, bytes); SPOOL_ERROR.flush()
         if hr != 0 or bytes != len(data):
-          raise "win32file.WriteFile() passed %i bytes and returned %i, %i" % (len(data), hr, bytes)
+          raise Exception("win32file.WriteFile() passed %i bytes and returned %i, %i" % (len(data), hr, bytes))
 
     srcHandle.Close()
 
